@@ -25,6 +25,9 @@ namespace iptvsimple
       int GetUniqueId() const { return m_uniqueId; }
       void SetUniqueId(int value) { m_uniqueId = value; }
 
+      int GetPosition() const { return m_position; }
+      void SetPosition(int value) { m_position = value; }
+
       const std::string& GetGroupName() const { return m_groupName; }
       void SetGroupName(const std::string& value) { m_groupName = value; }
 
@@ -38,6 +41,7 @@ namespace iptvsimple
     private:
       bool m_radio;
       int m_uniqueId;
+      int m_position;
       std::string m_groupName;
       std::vector<int> m_memberChannelIndexes;
     };
